==> ja-WiKicker-0.23.tbz: lib/perl5/site_perl/5.8.5/WiKicker/WikiCGI/Page/RssPage.pm <==
#
# WiKicker
#
#  RssPage.pm
#
#
# Copyright (C) 2003 WATANABE Yoshimasa <naney@naney.org>
#
# This file is part of the WiKicker.
#
# This program is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the Free
# Software Foundation; either version 2 of the License, or (at your option)
# any later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
# more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc., 59
# Temple Place, Suite 330, Boston, MA 02111-1307 USA
#
#
# $Id: RssPage.pm,v 1.3 2003/12/29 12:36:53 naney Exp $
#
#

package WiKicker::WikiCGI::Page::RssPage;

use 5.005;
use strict;
use WiKicker::WikiCGI::Page;
use WiKicker::PageName;
use WiKicker::URI;
use WiKicker::HTML;
use WiKicker::Time;
#use CGI;

use vars qw(@ISA);
@ISA = qw(WiKicker::WikiCGI::Page);

sub do_read {
  my $self = shift;

  my $db = $self->db;

  $db->shared_lock_pages;
  my $changes = $db->information('RecentChanges', 'changes');

  my @items;

  for my $record (@{$changes}) {
    my $name   = $record->[0];
    my $date   = $record->[1];
    my $link   = WiKicker::URI::make_read_page_url($self->request->query->url,
                                                   $name);
    my $description = $name;
    my $subject = $db->page_subject($name);
    if ($subject) {
      $description = $subject;
    }

    push(@items, [$name, $date, $link, $description, $subject]);
  }

  my $result = '';
  $result .= qq(<?xml version="1.0" encoding="UTF-8" ?>\n);

  $result .= $self->_open_rdf;

  my $about_uri = $self->request->query->url;
  my $link_uri = $about_uri;
  my $channel_title = $self->_get_properties('wikicker.name');
  my $channel_description =
    $self->_get_properties('param.RssPage.channel.description');
  unless ($channel_description) {
    $channel_description = $channel_title;
  }

  $channel_title = WiKicker::HTML::escape($channel_title);
  $channel_description = WiKicker::HTML::escape($channel_description);
  
  $result .= <<EOS;
<channel rdf:about="$about_uri">
<title>$channel_title</title>
<link>$link_uri</link>
<description>$channel_description</description>
EOS

  $result .= qq(<items>\n<rdf:Seq>\n);
  for my $item (@items) {
    my $resource = WiKicker::HTML::escape_attribute($item->[2]);
    $result .= qq(<rdf:li rdf:resource="$resource" />\n);
  }

  $result .= qq(</rdf:Seq>\n</items>\n</channel>\n);

  for my $item (@items) {
    my $about = WiKicker::HTML::escape_attribute($item->[2]);
    my $title = WiKicker::HTML::escape($item->[0]);
    my $link = WiKicker::HTML::escape($item->[2]);
    my $description = WiKicker::HTML::escape($item->[3]);
    my $date = $item->[1];

    my $date_str = WiKicker::Time::gmtime_to_W3CDTF_UTC($date);

    $result .=<<EOS;
<item rdf:about="$about">
  <title>$title</title>
  <link>$link</link>
  <description>$description</description>
  <dc:date>$date_str</dc:date>
</item>
EOS
  }

  $result .= qq(</rdf:RDF>\n);

  $self->request->attribute('rss', $result);
  $self->request->attribute('editable', 0);

  return 'rss';
}

sub _open_rdf {
  return <<EOS;
<rdf:RDF
  xmlns="http://purl.org/rss/1.0"
  xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#"
  xmlns:dc="http://purl.org/dc/elements/1.1/">
EOS
}

1;

==> ja-WiKicker-0.26.tbz: lib/perl5/site_perl/5.8.9/WiKicker/WikiCGI/Page/RssPage.pm <==
#
# WiKicker
#
#  RssPage.pm
#
#
# Copyright (C) 2003 WATANABE Yoshimasa <naney@naney.org>
#
# This file is part of the WiKicker.
#
# This program is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the Free
# Software Foundation; either version 2 of the License, or (at your option)
# any later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
# more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc., 59
# Temple Place, Suite 330, Boston, MA 02111-1307 USA
#
#
# $Id: RssPage.pm,v 1.4 2004/12/13 12:53:46 naney Exp $
#
#

package WiKicker::WikiCGI::Page::RssPage;

use 5.005;
use strict;
use WiKicker::WikiCGI::Page;
use WiKicker::PageName;
use WiKicker::URI;
use WiKicker::HTML;
use WiKicker::Time;
#use CGI;

use vars qw(@ISA);
@ISA = qw(WiKicker::WikiCGI::Page);

sub do_read {
  my $self = shift;

  my $db = $self->db;

  $db->shared_lock_pages;
  my $changes = $db->information('RecentChanges', 'changes');

  my @items;

  for my $record (@{$changes}) {
    my $name   = $record->[0];
    my $date   = $record->[1];
    my $link   = WiKicker::URI::make_read_page_url($self->request->query->url,
                                                   $name);
    my $description = $name;
    my $subject = $db->page_subject($name);
    if ($subject) {
      $description = $subject;
    }

    push(@items, [$name, $date, $link, $description, $subject]);
  }

  my $result = '';
  $result .= qq(<?xml version="1.0" encoding="UTF-8" ?>\n);

  $result .= $self->_open_rdf;

  my $about_uri = $self->request->query->url;
  my $link_uri = $about_uri;
  my $channel_title = $self->_get_properties('wikicker.name');
  my $channel_description =
    $self->_get_properties('param.RssPage.channel.description');
  unless ($channel_description) {
    $channel_description = $channel_title;
  }

  $channel_title = WiKicker::HTML::escape($channel_title);
  $channel_description = WiKicker::HTML::escape($channel_description);

  $result .= <<EOS;
<channel rdf:about="$about_uri">
<title>$channel_title</title>
<link>$link_uri</link>
<description>$channel_description</description>
EOS

  $result .= qq(<items>\n<rdf:Seq>\n);
  for my $item (@items) {
    my $resource = WiKicker::HTML::escape_attribute($item->[2]);
    $result .= qq(<rdf:li rdf:resource="$resource" />\n);
  }

  $result .= qq(</rdf:Seq>\n</items>\n</channel>\n);

  for my $item (@items) {
    my $about = WiKicker::HTML::escape_attribute($item->[2]);
    my $title = WiKicker::HTML::escape($item->[0]);
    my $link = WiKicker::HTML::escape($item->[2]);
    my $description = WiKicker::HTML::escape($item->[3]);
    my $date = $item->[1];

    my $date_str = WiKicker::Time::gmtime_to_W3CDTF_UTC($date);

    $result .=<<EOS;
<item rdf:about="$about">
  <title>$title</title>
  <link>$link</link>
  <description>$description</description>
  <dc:date>$date_str</dc:date>
</item>
EOS
  }

  $result .= qq(</rdf:RDF>\n);

  $self->request->attribute('rss', $result);
  $self->request->attribute('editable', 0);

  return 'rss';
}

sub _open_rdf {
  return <<EOS;
<rdf:RDF
  xmlns="http://purl.org/rss/1.0/"
  xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#"
  xmlns:dc="http://purl.org/dc/elements/1.1/">
EOS
}

1;
